@@ -87,6 +87,7 @@ VideoWindow::VideoWindow( QWidget *parent )
         , m_subLanguages( new QActionGroup( this ) )
         , m_audioLanguages( new QActionGroup( this ) )
         , m_logo( new QLabel( this ) )
+        , m_initialOffset( 0 )
         , m_aDataOutput(0)
 {
 
@@ -206,7 +207,6 @@ VideoWindow::load( const KUrl &url )
         m_media->setCurrentSource( url );
     m_justLoaded = true;
     m_adjustedSize=false;
-    engine()->play();
 
     QApplication::restoreOverrideCursor();
 
@@ -220,10 +220,8 @@ VideoWindow::play( qint64 offset )
     QApplication::setOverrideCursor( Qt::WaitCursor );
 
     m_justLoaded = false;
-    if( offset > 0 )
-        seek( offset );
+    m_initialOffset = offset;
     m_media->play();
-    kDebug() << "Does this media have Video stream? " << TheStream::hasVideo();
 
     QApplication::restoreOverrideCursor();
 
@@ -267,14 +265,18 @@ VideoWindow::playDisc(const Solid::Device& device )
         Phonon::DiscType phononType = Phonon::NoDisc;
         {
             Solid::OpticalDisc::ContentTypes solidType = disc->availableContent();
-            if( solidType & Solid::OpticalDisc::VideoDvd )
+            if (solidType & Solid::OpticalDisc::VideoDvd)
                 phononType = Phonon::Dvd;
-            else if( solidType & ( Solid::OpticalDisc::VideoCd | Solid::OpticalDisc::SuperVideoCd ) )
+            if (solidType & (Solid::OpticalDisc::VideoCd | Solid::OpticalDisc::SuperVideoCd))
                 phononType = Phonon::Vcd;
-            else if( solidType &  Solid::OpticalDisc::Audio )
+            if (solidType & Solid::OpticalDisc::Audio)
                 phononType = Phonon::Cd;
-            else
-            {
+
+            // No change -> cannot play the disc.... should not really happen as
+            // mainWindow already preprocesses the type, so this would indicate
+            // bogus handling in one of the classes -> assertation.
+            Q_ASSERT(phononType != Phonon::NoDisc);
+            if (phononType == Phonon::NoDisc){
                 kDebug() << "not a playable disc type: " << disc->availableContent() << " type";
                 return false;
             }
@@ -424,16 +426,6 @@ VideoWindow::isMuted()
 void
 VideoWindow::seek( qint64 pos )
 {
-//    bool wasPaused = false;
-
-    // If we seek to the end the track ended event is sent, but it is
-    // delayed as it happens in xine-event loop and before that we are
-    // already processing the next seek event (if user uses mouse wheel
-    // or keyboard to seek) and this causes the ui to think video is
-    // stopped but xine is actually playing the track. Tada!
-    // TODO set state based on events from xine only
-
-      m_media->pause(); //pausing first gives Phonon a chance to recognize seekable media;
       m_media->seek( pos );
 }
 
@@ -517,6 +509,11 @@ kDebug() << "chapters: " << m_controller->availableChapters() << " titles: " <<
     states << QLatin1String( "Loading" ) << QLatin1String( "Stopped" ) << QLatin1String( "Playing" ) << QLatin1String( "Buffering" ) << QLatin1String( "Paused" ) << QLatin1String( "Error" );
     kDebug() << "going from " << states.at(oldstate) << " to " << states.at(currentState);
 
+    if( currentState == Phonon::PlayingState && m_initialOffset > 0) {
+        seek(m_initialOffset);
+        m_initialOffset = 0;
+    }
+
     if( currentState == Phonon::PlayingState  && m_media->hasVideo() )
     {
         m_logo->hide();
